@@ -1,18 +1,17 @@
-from resttouch.serializators import PlainText
+import inspect
+import types
+import sys
 
-__all__ = ('PathParam', 'QueryParam', 'BodyParam')
+__all__ = ('PathParam', 'QueryParam', 'BodyParam', 'FileParam')
 
 
 class Param(object):
     required = True
     
     def __init__(self, value, default=None):
-        self.value = str(value)
+        self.value = value
         self.default = default
 
-    def __str__(self, str):
-        return str
-
 
 class PathParam(Param):
     pass
@@ -24,11 +23,15 @@ class QueryParam(Param):
         super(QueryParam, self).__init__(*args, **kwargs)
 
 
-class BodyParam(Param):
-    def __init__(self, value='body', default=None, serializator=PlainText):
-        self.serializator = serializator()
-        self.value = value
-        self.default = default
+class DataParam(Param):
+    pass
 
-    def __str__(self, str):
-        return self.serializator.serialize(str)
\ No newline at end of file
+
+class FileParam(Param):
+    pass
+
+
+param_types = {}
+for name, cls in inspect.getmembers(sys.modules[__name__]):
+    if isinstance(cls, (types.TypeType, Param)):
+        param_types[name] = cls
\ No newline at end of file
